@@ -18,10 +18,12 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <libglom/libglom_config.h> //For VERSION, GLOM_ENABLE_CLIENT_ONLY, GLOM_ENABLE_SQLITE
+
 #include "application.h"
 #include "dialog_existing_or_new.h"
 
-#include <glom/libglom/dialog_progress_creating.h>
+#include <libglom/dialog_progress_creating.h>
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 #include <glom/translation/dialog_change_language.h>
@@ -29,13 +31,11 @@
 #include <glom/utility_widgets/filechooserdialog_saveextras.h>
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-#include <glom/libglom/utils.h>
-#include <glom/libglom/glade_utils.h>
+#include <libglom/utils.h>
+#include <libglom/glade_utils.h>
 
-#include <glom/libglom/connectionpool_backends/postgres_central.h>
-#include <glom/libglom/connectionpool_backends/postgres_self.h>
-
-#include "config.h" //For VERSION.
+//#include <libglom/connectionpool_backends/postgres_central.h>
+//#include <libglom/connectionpool_backends/postgres_self.h>
 
 #include <cstdio>
 #include <memory> //For std::auto_ptr<>
@@ -113,7 +113,8 @@ App_Glom::App_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml
   m_menu_print_layouts_ui_merge_id(0),
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   m_ui_save_extra_showextras(false),
-  m_ui_save_extra_newdb_hosting_mode(Document_Glom::POSTGRES_CENTRAL_HOSTED),
+  m_ui_save_extra_newdb_hosting_mode(Document_Glom::DEFAULT_HOSTED),
+
 #endif // !GLOM_ENABLE_CLIENT_ONLY
   m_show_sql_debug(false)
 {
@@ -707,9 +708,11 @@ void App_Glom::open_browsed_document(const EpcServiceInfo* server, const Glib::u
     {
       // Connection is always remote-hosted in client only mode:
 #ifndef GLOM_ENABLE_CLIENT_ONLY
+#ifdef GLOM_ENABLE_POSTGRESQL
       //Stop the document from being self-hosted (it's already hosted by the other networked Glom instance):
-      if(document_temp.get_hosting_mode() == Document_Glom::POSTGRES_SELF_HOSTED)
-        document_temp.set_hosting_mode(Document_Glom::POSTGRES_CENTRAL_HOSTED);
+      if(document_temp.get_hosting_mode() == Document_Glom::HOSTING_MODE_POSTGRES_SELF)
+        document_temp.set_hosting_mode(Document_Glom::HOSTING_MODE_POSTGRES_CENTRAL);
+#endif //GLOM_ENABLE_POSTGRESQL
 #endif // !GLOM_ENABLE_CLIENT_ONLY
       // TODO: Error out in case this is a sqlite database, since we probably
       // can't access it from this host?
@@ -930,31 +933,44 @@ bool App_Glom::on_document_load()
         m_example_uri = pDocument->get_file_uri();
 
         pDocument->set_file_uri(Glib::ustring()); //Prevent it from defaulting to the read-only examples directory when offering saveas.
-
         //m_ui_save_extra_* are used by offer_saveas() if it's not empty:
         m_ui_save_extra_showextras = true;
         m_ui_save_extra_title = _("Creating From Example File");
         m_ui_save_extra_message = _("To use this example file you must save an editable copy of the file. A new database will also be created on the server.");
         m_ui_save_extra_newdb_title = "TODO";
-        m_ui_save_extra_newdb_hosting_mode = Document_Glom::POSTGRES_SELF_HOSTED;
+        m_ui_save_extra_newdb_hosting_mode = Document_Glom::DEFAULT_HOSTED;
+
+        
+        // Reinit cancelled state
+        set_operation_cancelled(false);
+        
         offer_saveas();
         // Note that bakery will try to add the example file itself to the
         // recently used documents, which is not what we want.
         m_ui_save_extra_message.clear();
         m_ui_save_extra_title.clear();
 
-        //Get the results from the extended save dialog:
-        pDocument->set_database_title(m_ui_save_extra_newdb_title);
-        pDocument->set_hosting_mode(m_ui_save_extra_newdb_hosting_mode);
-        m_ui_save_extra_newdb_hosting_mode = Document_Glom::POSTGRES_CENTRAL_HOSTED;
-
+        if(!get_operation_cancelled())
+        {	
+          //Get the results from the extended save dialog:
+          pDocument->set_database_title(m_ui_save_extra_newdb_title);
+          pDocument->set_hosting_mode(m_ui_save_extra_newdb_hosting_mode);
+          m_ui_save_extra_newdb_hosting_mode = Document_Glom::DEFAULT_HOSTED;
+          pDocument->set_is_example_file(false);
+          // We have a valid uri, so we can set it to !new and modified here
+        }        
+        
         m_ui_save_extra_newdb_title.clear();
         m_ui_save_extra_showextras = false;
 
         if(get_operation_cancelled())
+        {
+          pDocument->set_modified(false);
+          pDocument->set_is_new(true);
+          std::cout << "debug: user cancelled creating database" << std::endl;
           return false;
-        else
-          pDocument->set_is_example_file(false);
+        }
+        
 #else // !GLOM_ENABLE_CLIENT_ONLY
         // TODO_clientonly: Tell the user that opening example files is
         // not supported. This could alternatively also be done in
@@ -1059,11 +1075,14 @@ bool App_Glom::on_document_load()
           {
             // TODO: Do we need to call connection_pool->cleanup() here, for
             // stopping self-hosted databases? armin.
+            connection_pool->cleanup(this);
             //If the database was not successfully recreated:
             if(!user_cancelled)
             {
               //Let the user try again.
               //A warning has already been shown.
+              //TODO: No, I don't think there is a warning.
+              std::cerr << "App_Glom::on_document_load(): recreate_database() failed." << std::endl;
               return offer_new_or_existing();
             }
             else
@@ -1209,10 +1228,8 @@ bool App_Glom::offer_new_or_existing()
         open_browsed_document(dialog->get_service_info(), dialog->get_service_name());
         break;
 #endif
-#ifndef GLOM_ENABLE_CLIENT_ONLY
       default:
         break;
-#endif // !GLOM_ENABLE_CLIENT_ONLY
       }
 
       //Check that a document was opened:
@@ -1243,7 +1260,7 @@ void App_Glom::existing_or_new_new()
   Glib::ustring db_title;
 
   m_ui_save_extra_showextras = true; //Offer self-hosting or central hosting, and offer the database title.
-  m_ui_save_extra_newdb_hosting_mode = Document_Glom::POSTGRES_SELF_HOSTED; /* Default to self-hosting */
+  m_ui_save_extra_newdb_hosting_mode = Document_Glom::DEFAULT_HOSTED; /* Default to self-hosting */
   m_ui_save_extra_newdb_title.clear();
   offer_saveas();
 
@@ -1255,13 +1272,13 @@ void App_Glom::existing_or_new_new()
     const Glib::ustring db_title = m_ui_save_extra_newdb_title;
     Document_Glom::HostingMode hosting_mode = m_ui_save_extra_newdb_hosting_mode;
     m_ui_save_extra_newdb_title.clear();
-    m_ui_save_extra_newdb_hosting_mode = Document_Glom::POSTGRES_CENTRAL_HOSTED;
+    m_ui_save_extra_newdb_hosting_mode = Document_Glom::DEFAULT_HOSTED;
 
     //Make sure that the user can do something with his new document:
     document->set_userlevel(AppState::USERLEVEL_DEVELOPER);
     // Try various ports if connecting to an existing database server instead
     // of self-hosting one:
-    document->set_connection_try_other_ports(m_ui_save_extra_newdb_hosting_mode == Document_Glom::POSTGRES_CENTRAL_HOSTED);
+    document->set_connection_try_other_ports(m_ui_save_extra_newdb_hosting_mode == Document_Glom::DEFAULT_HOSTED);
 
     //Each new document must have an associated new database,
     //so choose a name
@@ -1888,7 +1905,7 @@ void App_Glom::on_menu_file_save_as_example()
   m_ui_save_extra_title.clear();
   m_ui_save_extra_message.clear();
   m_ui_save_extra_newdb_title.clear();
-  m_ui_save_extra_newdb_hosting_mode = Document_Glom::POSTGRES_CENTRAL_HOSTED;
+  m_ui_save_extra_newdb_hosting_mode = Document_Glom::DEFAULT_HOSTED;
 
   Glib::ustring file_uri = ui_file_select_save(file_uriOld); //Also asks for overwrite confirmation.
   if(!file_uri.empty())
@@ -1925,13 +1942,13 @@ void App_Glom::on_menu_file_save_as_example()
 
         //std::cout << "debug: table_name=" << table_name << std::endl;
 
-        Glib::ustring row_text;
+        Document_Glom::type_example_rows example_rows;
         FoundSet found_set;
         found_set.m_table_name = table_name;
-        m_pFrame->export_data_to_string(row_text, found_set, sequence);
+        m_pFrame->export_data_to_vector(example_rows, found_set, sequence);
         //std::cout << "  debug after row_text=" << row_text << std::endl;
 
-        document->set_table_example_data(table_name, row_text);
+        document->set_table_example_data(table_name, example_rows);
       }
 
       document->set_allow_autosave(true);
@@ -2062,7 +2079,7 @@ Glib::ustring App_Glom::ui_file_select_save(const Glib::ustring& old_file_uri) /
   //Create the appropriate dialog, depending on how the caller set m_ui_save_extra_showextras:
   if(m_ui_save_extra_showextras)
   {
-    fileChooser_SaveExtras = new Glom::FileChooserDialog_SaveExtras(gettext("Save Document"), Gtk::FILE_CHOOSER_ACTION_SAVE);
+    fileChooser_SaveExtras = new Glom::FileChooserDialog_SaveExtras(_("Save Document"), Gtk::FILE_CHOOSER_ACTION_SAVE);
     fileChooser_Save.reset(fileChooser_SaveExtras);
   }
   else
@@ -2169,7 +2186,7 @@ Glib::ustring App_Glom::ui_file_select_save(const Glib::ustring& old_file_uri) /
         if(!uri_is_writable(file))
         {
            //Warn the user:
-           ui_warning(gettext("Read-only File."), gettext("You may not overwrite the existing file, because you do not have sufficient access rights."));
+           ui_warning(gettext("Read-only File."), _("You may not overwrite the existing file, because you do not have sufficient access rights."));
            try_again = true; //Try again.
            continue;
         }
@@ -2183,7 +2200,7 @@ Glib::ustring App_Glom::ui_file_select_save(const Glib::ustring& old_file_uri) /
         if(!uri_is_writable(parent))
         {
           //Warn the user:
-           ui_warning(gettext("Read-only Directory."), gettext("You may not create a file in this directory, because you do not have sufficient access rights."));
+           ui_warning(gettext("Read-only Directory."), _("You may not create a file in this directory, because you do not have sufficient access rights."));
            try_again = true; //Try again.
            continue;
         }
@@ -2206,12 +2223,22 @@ Glib::ustring App_Glom::ui_file_select_save(const Glib::ustring& old_file_uri) /
           continue;
         }
       }
- 
+
+      bool is_self_hosted = false;
+
+#ifdef GLOM_ENABLE_POSTGRESQL
+      if(m_ui_save_extra_newdb_hosting_mode == Document_Glom::HOSTING_MODE_POSTGRES_SELF)
+        is_self_hosted = true;
+#endif //GLOM_ENABLE_POSTGRESQL
+
+#ifdef GLOM_ENABLE_SQLITE
+      if(m_ui_save_extra_newdb_hosting_mode == Document_Glom::HOSTING_MODE_SQLITE)
+        is_self_hosted = true;
+#endif // GLOM_ENABLE_SQLITE
+
       // Create a directory for self-hosted databases (sqlite or self-hosted
       // postgresql).
-      if(!try_again && fileChooser_SaveExtras &&
-         (m_ui_save_extra_newdb_hosting_mode == Document_Glom::POSTGRES_SELF_HOSTED ||
-          m_ui_save_extra_newdb_hosting_mode == Document_Glom::SQLITE_HOSTED))
+      if(!try_again && fileChooser_SaveExtras && is_self_hosted)
       {
         //Check that the directory does not exist already.
         //The GtkFileChooser could not check for that because it could not know that we would create a directory based on the filename:
@@ -2370,11 +2397,11 @@ void App_Glom::document_history_add(const Glib::ustring& file_uri)
   if(!file_uri.empty())
   {
     prevent = (file_uri == m_example_uri);
+    if(prevent)
+      return;
   }
 
-  // Call the base class:
-  if(!prevent)
-    Bakery::App_WithDoc_Gtk::document_history_add(file_uri);
+  Bakery::App_WithDoc_Gtk::document_history_add(file_uri);
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
