@@ -23,9 +23,9 @@
 
 #include <gtkmm/combobox.h>
 #include <libglademm.h>
-#include <glom/libglom/data_structure/relationship.h>
-#include <glom/libglom/document/document_glom.h>
-#include <glom/libglom/sharedptr.h>
+#include <libglom/data_structure/relationship.h>
+#include <libglom/document/document_glom.h>
+#include <libglom/sharedptr.h>
 
 #include <gtkmm/treestore.h>
 
@@ -57,7 +57,7 @@ public:
   ///Select the parent table.
   void set_selected_parent_table(const Glib::ustring& table_name, const Glib::ustring& table_title = Glib::ustring());
 
-protected:
+private:
 
   //void on_cell_data_name(const Gtk::TreeModel::const_iterator& iter);
   void on_cell_data_title(const Gtk::TreeModel::const_iterator& iter);
