@@ -19,9 +19,9 @@
  */
 
 #include "dialog_import_csv.h"
-#include "config.h"
+#include <libglom/libglom_config.h>
 
-#include <glom/libglom/data_structure/glomconversions.h>
+#include <libglom/data_structure/glomconversions.h>
 
 #include <gtkmm/messagedialog.h>
 #include <gtkmm/cellrenderercombo.h>
@@ -258,7 +258,7 @@ Dialog_Import_CSV::Dialog_Import_CSV(BaseObjectType* cobject, const Glib::RefPtr
     iter = m_encoding_model->append();
     if(ENCODINGS[i].name != NULL)
     {
-      (*iter)[m_encoding_columns.m_col_name] = gettext(ENCODINGS[i].name);
+      (*iter)[m_encoding_columns.m_col_name] = _(ENCODINGS[i].name);
       (*iter)[m_encoding_columns.m_col_charset] = ENCODINGS[i].charset;
     }
   }
@@ -425,7 +425,7 @@ void Dialog_Import_CSV::encoding_data_func(const Gtk::TreeModel::iterator& iter,
   renderer.set_property("text", encoding_display(name, charset));
 }
 
-bool Dialog_Import_CSV::row_separator_func(const Glib::RefPtr<Gtk::TreeModel>& model, const Gtk::TreeModel::iterator& iter) const
+bool Dialog_Import_CSV::row_separator_func(const Glib::RefPtr<Gtk::TreeModel>& /* model */, const Gtk::TreeModel::iterator& iter) const
 {
   return (*iter)[m_encoding_columns.m_col_name] == "";
 }
@@ -910,7 +910,7 @@ void Dialog_Import_CSV::field_data_func(Gtk::CellRenderer* renderer, const Gtk::
       if(field->get_glom_type() != Field::TYPE_IMAGE)
       {
         /* Exported data is always stored in postgres format */
-        Gnome::Gda::Value value = field->from_sql(orig_text, Field::SQL_FORMAT_POSTGRES, success);
+        const Gnome::Gda::Value value = field->from_file_format(orig_text, success);
         
         if(!success)
           text = _("<Import Failure>");
