@@ -21,7 +21,7 @@
 #ifndef FILECHOOSER_EXPORT_GLOM_H
 #define FILECHOOSER_EXPORT_GLOM_H
 
-#include <glom/libglom/document/document_glom.h>
+#include <libglom/document/document_glom.h>
 #include <gtkmm/filechooserdialog.h>
 
 namespace Glom
@@ -40,7 +40,7 @@ public:
 
   void get_layout_groups(Document_Glom::type_list_layout_groups& layout_groups) const;
 
-protected:
+private:
 
   void on_button_define_layout();
   void on_dialog_layout_hide();
