@@ -25,7 +25,7 @@
 
 #include <gtkmm.h>
 #include <libglademm.h>
-#include <glom/libglom/data_structure/layout/layoutitem_button.h>
+#include <libglom/data_structure/layout/layoutitem_button.h>
 #include "../base_db.h"
 
 #include <gtksourceviewmm/sourceview.h>
@@ -46,7 +46,7 @@ public:
   sharedptr<LayoutItem_Button> get_script() const;
   void get_script (const sharedptr<LayoutItem_Button>& script) const;
 
-protected:
+private:
   void on_button_test();
 
   Gtk::Entry* m_entry_title;
