@@ -23,8 +23,8 @@
 
 #include <gtkmm.h>
 #include "../utility_widgets/dialog_properties.h"
-#include <glom/libglom/document/document_glom.h>
-#include <glom/libglom/data_structure/layout/report_parts/layoutitem_fieldsummary.h>
+#include <libglom/document/document_glom.h>
+#include <libglom/data_structure/layout/report_parts/layoutitem_fieldsummary.h>
 #include "../box_withbuttons.h"
 #include "../utility_widgets/combo_textglade.h"
 #include "combo_summarytype.h"
@@ -49,7 +49,7 @@ public:
 
   sharedptr<LayoutItem_FieldSummary> get_item() const;
 
-protected:
+private:
   //Signal handlers:
   void on_button_field();
 
