@@ -21,18 +21,25 @@
 
 #include "dialog_imageobject.h"
 #include "../python_embed/glom_python.h"
-#include <glom/libglom/data_structure/glomconversions.h>
+#include <libglom/data_structure/glomconversions.h>
 
 //#include <libgnome/gnome-i18n.h>
 #include <glibmm/i18n.h>
 
-Dialog_ImageObject::Dialog_ImageObject(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
-: Gtk::Dialog(cobject)
+namespace Glom
 {
-  refGlade->get_widget("entry_title",  m_entry_title);
-  refGlade->get_widget_derived("imageglom",  m_image);
 
-  refGlade->get_widget("button_choose_image",  m_button_choose_image);
+Dialog_ImageObject::Dialog_ImageObject(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
+: Gtk::Dialog(cobject),
+  m_box_title(0),
+  m_entry_title(0),
+  m_image(0)
+{
+  refGlade->get_widget("hbox_title", m_box_title);
+  refGlade->get_widget("entry_title", m_entry_title);
+  refGlade->get_widget_derived("imageglom", m_image);
+
+  refGlade->get_widget("button_choose_image", m_button_choose_image);
   m_button_choose_image->signal_clicked().connect(sigc::mem_fun(*this, &Dialog_ImageObject::on_button_choose));
 
   //on_foreach_connect(*this);
@@ -52,7 +59,7 @@ void Dialog_ImageObject::on_button_choose()
 }
 
 
-void Dialog_ImageObject::set_imageobject(const sharedptr<const LayoutItem_Image>& imageobject, const Glib::ustring& table_name)
+void Dialog_ImageObject::set_imageobject(const sharedptr<const LayoutItem_Image>& imageobject, const Glib::ustring& table_name, bool show_title)
 {
   //set_blocked();
 
@@ -62,6 +69,11 @@ void Dialog_ImageObject::set_imageobject(const sharedptr<const LayoutItem_Image>
   m_entry_title->set_text(imageobject->get_title());
   m_image->set_value( imageobject->get_image() );
 
+  if(show_title)
+    m_box_title->show();
+  else
+    m_box_title->hide();
+
   //set_blocked(false);
 
   //Dialog_Properties::set_modified(false);
@@ -77,6 +89,8 @@ sharedptr<LayoutItem_Image> Dialog_ImageObject::get_imageobject() const
   return result;
 }
 
+} //namespace Glom
+
 
 
 
