@@ -18,9 +18,9 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <glom/libglom/connectionpool_backends/postgres_self.h>
-#include <glom/libglom/utils.h>
-#include <glom/libglom/spawn_with_feedback.h>
+#include <libglom/connectionpool_backends/postgres_self.h>
+#include <libglom/utils.h>
+#include <libglom/spawn_with_feedback.h>
 #include <glib/gstdio.h> // For g_remove
 
 #include <bakery/bakery.h>
@@ -381,7 +381,7 @@ bool PostgresSelfHosted::startup(Gtk::Window* parent_window)
   // POSTGRES_UTILS_PATH is defined in config.h, based on the configure.
   // Make sure to use double quotes for the executable path, because the
   // CreateProcess() API used on Windows does not support single quotes.
-  const std::string command_postgres_start = "\"" + get_path_to_postgres_executable("postmaster") + "\" -D \"" + dbdir_data + "\" "
+  const std::string command_postgres_start = "\"" + get_path_to_postgres_executable("postgres") + "\" -D \"" + dbdir_data + "\" "
                                   + " -p " + port_as_text
                                   + " -i " //Equivalent to -h "*", which in turn is equivalent to listen_addresses in postgresql.conf. Listen to all IP addresses, so any client can connect (with a username+password)
                                   + " -c hba_file=\"" + dbdir + "/config/pg_hba.conf\""
