@@ -41,7 +41,7 @@ public:
   bool get_use_custom_title() const;
   void set_use_custom_title(bool use_custom_title = true);
 
-protected:
+private:
 
   //We need this in order to specify that an empty custom title should really be used.
   bool m_use_custom_title;
