@@ -1,6 +1,6 @@
 /* Glom
  *
- * Copyright (C) 2001-2004 Murray Cumming
+ * Copyright (C) 2001-2009 Murray Cumming
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,55 +21,52 @@
 #ifndef DOCUMENT_GLOM_H
 #define DOCUMENT_GLOM_H
 
-#include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
+#include <libglom/libglom_config.h> // For GLOM_ENABLE_CLIENT_ONLY, GLOM_ENABLE_SQLITE
 
 #include <bakery/Document/Document_XML.h>
 #include <bakery/View/View_Composite.h>
-#include <glom/libglom/data_structure/relationship.h>
-#include <glom/libglom/data_structure/field.h>
-#include <glom/libglom/data_structure/layout/layoutgroup.h>
-#include <glom/libglom/data_structure/layout/layoutitem_notebook.h>
-#include <glom/libglom/data_structure/layout/layoutitem_portal.h>
-#include <glom/libglom/data_structure/layout/layoutitem_button.h>
-#include <glom/libglom/data_structure/layout/layoutitem_text.h>
-#include <glom/libglom/data_structure/layout/layoutitem_image.h>
-#include <glom/libglom/data_structure/tableinfo.h>
-#include <glom/libglom/data_structure/groupinfo.h>
-#include <glom/libglom/data_structure/report.h>
-#include <glom/libglom/data_structure/print_layout.h>
-#include <glom/libglom/data_structure/foundset.h>
+#include <libglom/data_structure/relationship.h>
+#include <libglom/data_structure/field.h>
+#include <libglom/data_structure/layout/layoutgroup.h>
+#include <libglom/data_structure/layout/layoutitem_notebook.h>
+#include <libglom/data_structure/layout/layoutitem_portal.h>
+#include <libglom/data_structure/layout/layoutitem_button.h>
+#include <libglom/data_structure/layout/layoutitem_text.h>
+#include <libglom/data_structure/layout/layoutitem_image.h>
+#include <libglom/data_structure/tableinfo.h>
+#include <libglom/data_structure/groupinfo.h>
+#include <libglom/data_structure/report.h>
+#include <libglom/data_structure/print_layout.h>
+#include <libglom/data_structure/foundset.h>
 #include "../appstate.h"
-#include <gtkmm/window.h>
+//#include <gtkmm/window.h>
 #include <vector>
 #include <map>
 #include <limits> // for numeric_limits
 
+// Instructions to swig, telling it what Java API to generate:
+#ifdef SWIG
+%module glom
+%include "std_string.i"
+%include "std_vector.i"
+%include "typemaps.i"
+
+%inline %{ typedef unsigned int guint; %}
+%inline %{ namespace Glib { typedef std::string ustring; } %}
+
+//Stick to the client-only API for swig, for now.
+//TODO: Watch out if some of these are virtual.
+#define GLOM_ENABLE_CLIENT_ONLY 1
+#endif //SWIG
+
+namespace Gtk
+{
+class Window;
+}
+
 namespace Glom
 {
 
-/// Can be used with std::find_if() to find a layout with the same parent_table and layout_name.
-template<class T_Element>
-class predicate_Layout
-{
-public:
-  predicate_Layout(const Glib::ustring& parent_table, const Glib::ustring& layout_name, const Glib::ustring& layout_platform)
-  : m_parent_table(parent_table),
-    m_layout_name(layout_name),
-    m_layout_platform(layout_platform)
-  {
-  }
-
-  bool operator() (const T_Element& element)
-  {
-    return (element.m_parent_table == m_parent_table) &&
-           (element.m_layout_name == m_layout_name) &&
-           (element.m_layout_platform == m_layout_platform);
-  }
-
-protected:
-  Glib::ustring m_parent_table, m_layout_name, m_layout_platform;
-};
-
 class Document_Glom : public Bakery::Document_XML
 {
 public: 
@@ -110,14 +107,27 @@ public:
 
   static guint get_latest_known_document_format_version();
 
+  /// How the database is hosted.
   enum HostingMode
   {
-    POSTGRES_CENTRAL_HOSTED, /*!< The database is hosted on an external postgresql server. */
-    POSTGRES_SELF_HOSTED, /*!< A new postgres database process is spawned that hosts the data. */
-    SQLITE_HOSTED /*!< A sqlite database file is used. */
+    //Only enabled if GLOM_ENABLE_POSTGRESQL is defined:
+    HOSTING_MODE_POSTGRES_CENTRAL, /*!< The database is hosted on an external postgresql server. */
+    
+    //Only enabled if GLOM_ENABLE_POSTGRESQL is defined and GLOM_ENABLE_CLIENT_ONLY is not defined:
+    HOSTING_MODE_POSTGRES_SELF, /*!< A new postgres database process is spawned that hosts the data. */
+
+    //Only enabled if GLOM_ENABLE_SQLITE is defined:
+    HOSTING_MODE_SQLITE, /*!< A sqlite database file is used. */
+
+    //This reduces the ifdefs elsewhere:
+#ifdef GLOM_ENABLE_POSTGRESQL
+    DEFAULT_HOSTED = HOSTING_MODE_POSTGRES_SELF
+#else
+    DEFAULT_HOSTED = HOSTING_MODE_SQLITE
+#endif
   };
 
-  /** Set the hosting mode of the database.
+  /** Set the hosting mode of the database. 
    */
   void set_hosting_mode(HostingMode mode);
 
@@ -127,7 +137,7 @@ public:
   void set_connection_port(int port_number);
   void set_connection_try_other_ports(bool val);
 
-  /** This returns how the hosting mode of the database.
+  /** This returns how the database is hosted.
    */
   HostingMode get_hosting_mode() const;
 
@@ -173,8 +183,7 @@ public:
   /** Returns whether the field is the from-field in a to-one relationship.
    * @see get_relationship_is_to_one(). Ignores hidden tables.
    */
-  sharedptr<Relationship> get_field_used_in_relationship_to_one(const Glib::ustring& table_name, const Glib::ustring& field_name) const;
-
+  sharedptr<Relationship> get_field_used_in_relationship_to_one(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& layout_field) const;
 
   typedef std::vector< sharedptr<Field> > type_vecFields;
   type_vecFields get_table_fields(const Glib::ustring& table_name) const;
@@ -262,14 +271,17 @@ public:
   Glib::ustring get_table_title(const Glib::ustring& table_name) const;
   void set_table_title(const Glib::ustring& table_name, const Glib::ustring& value);
 
+  typedef std::vector< Gnome::Gda::Value > type_row_data;
+  typedef std::vector< type_row_data > type_example_rows;
+
   /** Save example data into the document, for use when creating the example database on the server.
    * Don't use this for large amounts of data.
    * @param table_name The table that should contain this example data.
    * @param rows Each row is separated by a newline. Each line has comma-separated field values, in SQL format.
    */
-  void set_table_example_data(const Glib::ustring& table_name, const Glib::ustring& rows);
+  void set_table_example_data(const Glib::ustring& table_name, const type_example_rows& rows);
 
-  Glib::ustring get_table_example_data(const Glib::ustring& table_name) const;
+  type_example_rows get_table_example_data(const Glib::ustring& table_name) const;
 
   virtual Glib::ustring get_name() const; //override.
 
@@ -336,17 +348,17 @@ public:
 
   FoundSet get_criteria_current(const Glib::ustring& table_name) const;
 
-
+#ifndef SWIG //Hide this API from swig.
   // Used by Relationship Overview dialog to preserve table locations accross instantiations:
     
-  /** Retrieve the x and y coordinates for the given table position.
+  /** Retrieve the x and y coordinates for the given table position in the relationship overview dialog.
    * 
    * @param table_name The name of the table to query.
    * @param x The x coordinate of the table position.
    * @param y The y coordinate of the table position.
-   * @return false if the table does not have any 
+   * @return false if the table does not have any position for this table.
    */
-  bool get_table_overview_position ( const Glib::ustring &table_name, float &x, float &y ) const;
+  bool get_table_overview_position( const Glib::ustring& table_name, float &x, float &y ) const;
     
   /** Set the position of a table in the relationship overview dialog.
    * 
@@ -354,7 +366,7 @@ public:
    * @param x The x coordinate of the table position.
    * @param y The y coordinate of the table position.
    */
-  void set_table_overview_position ( const Glib::ustring &table_name, float x, float y );
+  void set_table_overview_position( const Glib::ustring& utable_name, float x, float y );
     
   enum userLevelReason
   {
@@ -379,7 +391,9 @@ public:
   typedef sigc::signal<void, AppState::userlevels> type_signal_userlevel_changed;
   type_signal_userlevel_changed signal_userlevel_changed();
 
+  //TODO: This is a rather indirect way for application.cc to request the UI to update for the userlevel.
   void emit_userlevel_changed();
+#endif //SWIG
 
   static Glib::ustring get_default_layout_platform();
 
@@ -393,29 +407,38 @@ public:
 
 
 
+#ifndef SWIG //Hide this API from swig.
   void set_parent_window(Gtk::Window* window);
 
   Glib::ustring build_and_get_contents() const;
 
-  static sharedptr<TableInfo> create_table_system_preferences();
-  static sharedptr<TableInfo> create_table_system_preferences(type_vecFields& fields);
-  static sharedptr<Relationship>  create_relationship_system_preferences(const Glib::ustring& table_name);
-  static bool get_relationship_is_system_properties(const sharedptr<const Relationship>& relationship);
+protected:
+
+
+  //TODO: Remove this:
+  friend class ReportBuilder;
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   ///If value is equal to the default then no attribute will be set, to save text space in the XML file.
   static void set_node_attribute_value_as_decimal(xmlpp::Element* node, const Glib::ustring& strAttributeName, guint value, guint value_default = 0);
 #endif // !GLOM_ENABLE_CLIENT_ONLY
-
+  
   // This is required by the report builder, so it cannot be disabled
   // in client only mode
   static void set_node_attribute_value_as_decimal_double(xmlpp::Element* node, const Glib::ustring& strAttributeName, double value);
+#endif //SWIG
 
-protected:
+#ifndef SWIG
+public:
+  static sharedptr<TableInfo> create_table_system_preferences();
+  static sharedptr<TableInfo> create_table_system_preferences(type_vecFields& fields);
+  static sharedptr<Relationship> create_relationship_system_preferences(const Glib::ustring& table_name);
+  static bool get_relationship_is_system_properties(const sharedptr<const Relationship>& relationship);
+#endif //SWIG
 
+private:
   //Overrides:
 
-
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   virtual bool save_before();
   void save_before_layout_group(xmlpp::Element* node, const sharedptr<const LayoutGroup>& group, bool with_print_layout_positions = false);
@@ -455,8 +478,10 @@ protected:
   static void set_node_attribute_value_as_bool(xmlpp::Element* node, const Glib::ustring& strAttributeName, bool value = true, bool value_default = false);
   static void set_node_attribute_value_as_float( xmlpp::Element* node, const Glib::ustring& strAttributeName, float value );
   static void set_node_attribute_value_as_value(xmlpp::Element* node, const Glib::ustring& strAttributeName, const Gnome::Gda::Value& value, Field::glom_field_type field_type);
+  static void set_node_text_child_as_value(xmlpp::Element* node, const Gnome::Gda::Value& value, Field::glom_field_type field_type);
 #endif // !GLOM_ENABLE_CLIENT_ONLY
   static Gnome::Gda::Value get_node_attribute_value_as_value(const xmlpp::Element* node, const Glib::ustring& strAttributeName, Field::glom_field_type field_type);
+  static Gnome::Gda::Value get_node_text_child_as_value(const xmlpp::Element* node, Field::glom_field_type field_type);
 
   Glib::ustring get_child_text_node(const xmlpp::Element* node, const Glib::ustring& child_node_name) const;
   void set_child_text_node(xmlpp::Element* node, const Glib::ustring& child_node_name, const Glib::ustring& text);
@@ -540,7 +565,8 @@ protected:
     typedef std::map< Glib::ustring, sharedptr<PrintLayout> > type_print_layouts; //map of print layout names to print layouts
     type_print_layouts m_print_layouts;
 
-    Glib::ustring m_example_rows;
+    //Example data, used when creating a database from an example.
+    type_example_rows m_example_rows;
 
     //Per-session, not saved in document:
     typedef std::map<Glib::ustring, Gnome::Gda::Value> type_map_layout_primarykeys;
@@ -582,10 +608,6 @@ protected:
   Gtk::Window* m_parent_window; //Needed by BusyCursor.
 };
 
-//The base View for this document;
-typedef Bakery::View<Document_Glom> View_Glom;
-typedef Bakery::View_Composite<Document_Glom> View_Composite_Glom;
-
 } //namespace Glom
 
 #endif //DOCUMENT_GLOM_H
