@@ -24,10 +24,13 @@
 #define NO_IMPORT_PYGTK //To avoid a multiple definition in pygtk.
 #include <pygtk/pygtk.h> //For the PyGObject and PyGBoxed struct definitions.
 
-#include <glom/libglom/document/document_glom.h>
-#include <glom/libglom/data_structure/field.h>
+#include <libglom/document/document_glom.h>
+#include <libglom/data_structure/field.h>
 #include <glibmm/ustring.h>
 
+namespace Glom
+{
+
 class PyGlomRecord;
 
 struct PyGlomRelatedRecord
@@ -58,6 +61,7 @@ void PyGlomRelatedRecord_SetRelationship(PyGlomRelatedRecord* self, const shared
 void PyGlomRelatedRecord_SetConnection(PyGlomRelatedRecord* self, const Glib::RefPtr<Gnome::Gda::Connection>& connection);
 */
 
+} //namespace Glom
 
 
 #endif //GLOM_PYTHON_GLOM_RELATEDRECORD_H
