@@ -20,8 +20,8 @@
 
 #include "box_data_list_related.h"
 #include "dialog_layout_list_related.h"
-#include <glom/libglom/data_structure/glomconversions.h>
-#include <glom/libglom/glade_utils.h>
+#include <libglom/data_structure/glomconversions.h>
+#include <libglom/glade_utils.h>
 #include <glom/frame_glom.h> //For show_ok_dialog()
 #include <bakery/App/App_Gtk.h> //For util_bold_message().
 #include <glibmm/i18n.h>
@@ -240,7 +240,7 @@ void Box_Data_List_Related::on_adddel_record_added(const Gtk::TreeModel::iterato
   //primary_key_value is a new autogenerated or human-entered key for the row.
   //It has already been added to the database.
   //Gnome::Gda::Value primary_key_value = m_AddDel.get_value_key(row);
-  std::cout << "Box_Data_List_Related::on_adddel_record_added(): primary_key_value=" << primary_key_value.to_string() << std::endl;
+  //std::cout << "Box_Data_List_Related::on_adddel_record_added(): primary_key_value=" << primary_key_value.to_string() << std::endl;
 
 
   if(!row)
@@ -276,11 +276,14 @@ void Box_Data_List_Related::on_adddel_record_added(const Gtk::TreeModel::iterato
     //Create the link by setting the foreign key
     if(m_key_field && m_portal)
     {
+      Glib::RefPtr<Gnome::Gda::Set> params = Gnome::Gda::Set::create();
+      params->add_holder(m_key_field->get_holder(m_key_value));
+      params->add_holder(field_primary_key->get_holder(primary_key_value));
       Glib::ustring strQuery = "UPDATE \"" + m_portal->get_table_used(Glib::ustring() /* not relevant */) + "\"";
-      strQuery += " SET \"" +  /* get_table_name() + "." +*/ m_key_field->get_name() + "\" = " + m_key_field->sql(m_key_value);
-      strQuery += " WHERE \"" + get_table_name() + "\".\"" + field_primary_key->get_name() + "\" = " + field_primary_key->sql(primary_key_value);
-      std::cout << "Box_Data_List_Related::on_adddel_record_added(): setting value in db=" << primary_key_value.to_string() << std::endl;
-      const bool test = query_execute(strQuery, get_app_window());
+      strQuery += " SET \"" +  /* get_table_name() + "." +*/ m_key_field->get_name() + "\" = " + m_key_field->get_gda_holder_string();
+      strQuery += " WHERE \"" + get_table_name() + "\".\"" + field_primary_key->get_name() + "\" = " + field_primary_key->get_gda_holder_string();
+      //std::cout << "Box_Data_List_Related::on_adddel_record_added(): setting value in db=" << primary_key_value.to_string() << std::endl;
+      const bool test = query_execute(strQuery, params);
       if(test)
       {
         //Show it on the view, if it's visible:
