@@ -21,7 +21,7 @@
 #ifndef BOX_DATA_LIST_RELATED_H
 #define BOX_DATA_LIST_RELATED_H
 
-#include "config.h" // GLOM_ENABLE_CLIENT_ONLY
+#include <libglom/libglom_config.h> // GLOM_ENABLE_CLIENT_ONLY
 
 #include "box_data_portal.h"
 
