@@ -23,7 +23,7 @@
 
 #include <gtkmm.h>
 #include <libglademm.h>
-#include <glom/libglom/document/document_glom.h>
+#include <libglom/document/view.h>
 
 namespace Glom
 {
@@ -40,9 +40,10 @@ public:
 
   virtual bool init_db_details(const Glib::ustring& table_name);
 
-protected:
+private:
   virtual void on_button_close();
 
+protected:
   Gtk::Label* m_label_table;
   Gtk::Label* m_label_frame;
 };
