@@ -29,9 +29,10 @@
 //#include "../../utility_widgets/entry_numerical.h"
 #include "../../utility_widgets/dialog_properties.h"
 #include "../../utility_widgets/datawidget.h"
-#include <glom/libglom/data_structure/field.h>
+#include <libglom/data_structure/field.h>
 #include "../../layout_item_dialogs/box_formatting.h"
 #include "../../base_db.h"
+#include <gtksourceviewmm/sourceview.h>
 
 namespace Glom
 {
@@ -47,7 +48,7 @@ public:
   virtual void set_field(const sharedptr<const Field>& field, const Glib::ustring& table_name);
   virtual sharedptr<Field> get_field() const; //TODO_FieldShared
 
-protected:
+private:
 
   //Signal handlers:
   void on_combo_type_changed();
@@ -81,7 +82,7 @@ protected:
 
   Gtk::RadioButton* m_pRadio_Calculate;
   Gtk::Alignment* m_pAlignment_Calculate;
-  Gtk::TextView* m_pTextView_Calculation;
+  gtksourceview::SourceView* m_pTextView_Calculation;
   Gtk::Button* m_pButton_EditCalculation;
 
   Gtk::Entry* m_pEntry_Title;
