@@ -21,40 +21,56 @@
 #ifndef BOX_TABLES_H
 #define BOX_TABLES_H
 
-#include "../box_db.h"
+#include <glom/box_withbuttons.h>
+#include <glom/base_db.h>
+#include <glom/utility_widgets/adddel/adddel_withbuttons.h>
+#include <libglademm.h>
 
-class Box_Tables : public Box_DB
+namespace Glom
+{
+
+/** This widget offers a list of tables in the database,
+  * allowing the user to select a table,
+  * or add or delete a table.
+  */
+class Box_Tables 
+: public Box_WithButtons,
+  public Base_DB
 {
 public:
   Box_Tables(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
   virtual ~Box_Tables();
 
-protected:
+private:
   virtual bool fill_from_database(); //override
 
-  virtual void fill_table_row(const Gtk::TreeModel::iterator& iter, const TableInfo& table_info);
+  virtual void fill_table_row(const Gtk::TreeModel::iterator& iter, const sharedptr<const TableInfo>& table_info);
 
   virtual void save_to_document();
 
   //Signal handlers:
-  virtual void on_adddel_Add(const Gtk::TreeModel::iterator& row);
-  virtual void on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, const Gtk::TreeModel::iterator& rowEnd);
-  virtual void on_adddel_Edit(const Gtk::TreeModel::iterator& row);
-  virtual void on_adddel_changed(const Gtk::TreeModel::iterator& row, guint column);
-  
-  virtual void on_show_hidden_toggled();
+#ifndef GLOM_ENABLE_CLIENT_ONLY
+  void on_adddel_Add(const Gtk::TreeModel::iterator& row);
+  void on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, const Gtk::TreeModel::iterator& rowEnd);
+  void on_adddel_changed(const Gtk::TreeModel::iterator& row, guint column);
+#endif //GLOM_ENABLE_CLIENT_ONLY
+  void on_adddel_Edit(const Gtk::TreeModel::iterator& row);
+
+  void on_show_hidden_toggled();
 
   virtual void on_userlevel_changed(AppState::userlevels userlevel);
-
+      
   Gtk::Label* m_pLabelFrameTitle;
   Gtk::CheckButton* m_pCheckButtonShowHidden;
   guint m_colTableName;
   guint m_colHidden;
   guint m_colTitle;
   guint m_colDefault;
-  
+
   mutable AddDel_WithButtons m_AddDel; //mutable because its get_ methods aren't const.
 };
 
+} //namespace Glom
+
 #endif //BOX_TABLES_H
 
