@@ -24,9 +24,9 @@
 #include <eval.h> /* for PyEval_EvalCode */
 #include <objimpl.h> /* for PyObject_New() */
 
-#include <glom/libglom/python_embed/py_glom_record.h>
-#include <glom/libglom/python_embed/py_glom_related.h>
-#include <glom/libglom/python_embed/py_glom_relatedrecord.h>
+#include <libglom/python_embed/py_glom_record.h>
+#include <libglom/python_embed/py_glom_related.h>
+#include <libglom/python_embed/py_glom_relatedrecord.h>
 
 static PyMethodDef pyglom_methods[] = {
     {NULL, 0, 0, 0}  /* Sentinel */
