@@ -22,7 +22,7 @@
 #define GLOM_TRANSLATIONS_DIALOG_COPY_TRANSLATION_H
 
 #include "combobox_locale.h"
-#include <glom/libglom/document/document_glom.h> // For View_Composite_Glom
+#include <libglom/document/document_glom.h> // For View_Composite_Glom
 #include <libglademm.h>
 #include <gtkmm/dialog.h>
 
@@ -40,7 +40,7 @@ public:
 
   Glib::ustring get_locale() const;
 
-protected:
+private:
   ComboBox_Locale* m_combo_locale;
 };
 
