@@ -23,18 +23,22 @@
 #include "dialog_identify_original.h"
 #include "dialog_copy_translation.h"
 #include <bakery/App/App_Gtk.h> //For util_bold_message().
-#include "glom/libglom/utils.h"
-#include "glom/libglom/glade_utils.h"
+#include <libglom/utils.h>
+#include <libglom/glade_utils.h>
 
 #include <glibmm/i18n.h>
 #include <string.h> // for memset
 
 // To read the .po files
 #include <gettext-po.h>
-#include "config.h" //For HAVE_GETTEXTPO_XERROR
+#include <libglom/libglom_config.h> //For HAVE_GETTEXTPO_XERROR
 
 #include <sstream>
 
+/* For really ugly hacks! */
+#include <setjmp.h>
+
+
 namespace Glom
 {
 
