@@ -21,7 +21,7 @@
 #ifndef GLOM_MODE_DESIGN_COMBOENTRY_CURRENCY_HH
 #define GLOM_MODE_DESIGN_COMBOENTRY_CURRENCY_HH
 
-#include <glom/libglom/data_structure/iso_codes.h>
+#include <libglom/data_structure/iso_codes.h>
 #include <gtkmm/comboboxentry.h>
 #include <libglademm.h>
 
@@ -37,7 +37,7 @@ public:
   ComboEntry_Currency(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
   virtual ~ComboEntry_Currency();
 
-protected:
+private:
 
   //Tree model columns:
   //These columns are used by the model that is created by the default constructor
