@@ -21,14 +21,14 @@
 #ifndef GLOM_UTILITY_WIDGETS_DATAWIDGET_H
 #define GLOM_UTILITY_WIDGETS_DATAWIDGET_H
 
-#include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
+#include <libglom/libglom_config.h> // For GLOM_ENABLE_CLIENT_ONLY
 
 #include "placeholder.h"
-#include "layoutwidgetbase.h"
+#include "layoutwidgetmenu.h"
 #include <gtkmm/label.h>
-#include <glom/libglom/data_structure/field.h>
-#include <glom/libglom/document/document_glom.h>
-#include <glom/libglom/data_structure/layout/layoutitem_field.h>
+#include <libglom/data_structure/field.h>
+#include <libglom/document/view.h>
+#include <libglom/data_structure/layout/layoutitem_field.h>
 #include "../mode_data/treestore_layout.h" //Forthe enum.
 
 namespace Glom
@@ -38,7 +38,7 @@ class App_Glom;
 
 class DataWidget
  : public Gtk::EventBox,
-   public LayoutWidgetBase,
+   public LayoutWidgetMenu,
    public View_Composite_Glom
 {
 public:
@@ -60,6 +60,7 @@ public:
   virtual void set_editable(bool editable = true);
   virtual void set_viewable(bool viewable = true);
 
+  static sharedptr<LayoutItem_Field> offer_field_list(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& start_field, Document_Glom* document, App_Glom* app);
   sharedptr<LayoutItem_Field> offer_field_list(const Glib::ustring& table_name);
   sharedptr<LayoutItem_Field> offer_field_list(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& start_field);
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -76,7 +77,7 @@ public:
   typedef sigc::signal<void, const Gnome::Gda::Value&> type_signal_open_details_requested;
   type_signal_open_details_requested signal_open_details_requested();
 
-protected:
+private:
   //virtual void setup_menu();
 
   //Overrides of default signal handlers:
