@@ -21,11 +21,16 @@
 #ifndef GLOM_UTILITY_WIDGETS_ENTRY_GLOM_H
 #define GLOM_UTILITY_WIDGETS_ENTRY_GLOM_H
 
+#include <libglom/libglom_config.h> // For GLOM_ENABLE_CLIENT_ONLY
+
 #include <gtkmm.h>
-#include "../data_structure/field.h"
+#include <libglom/data_structure/field.h>
 #include "layoutwidgetfield.h"
 #include <libglademm.h>
 
+namespace Glom
+{
+
 class App_Glom;
 
 class EntryGlom
@@ -51,10 +56,12 @@ public:
 
   virtual void set_read_only(bool read_only = true);
 
-protected:
+private:
   void init();
 
   //Overrides of default signal handlers:
+  //Note that these don't override anything when GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
+  //is not defined. These are normal signal handlers then.
   virtual void on_changed(); //From Gtk::Entry.
   virtual void on_activate(); //From Gtk::Entry.
   virtual bool on_focus_out_event(GdkEventFocus* event); //From Gtk::Widget
@@ -62,7 +69,9 @@ protected:
 
   virtual void check_for_change();
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   virtual bool on_button_press_event(GdkEventButton *event); //override
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   virtual App_Glom* get_application();
 
@@ -72,5 +81,7 @@ protected:
   //Gnome::Gda::Value m_value; //The last-stored value. We have this because the displayed value might be unparseable.
 };
 
+} //namespace Glom
+
 #endif //GLOM_UTILITY_WIDGETS_ENTRY_GLOM_H
 
