@@ -24,7 +24,7 @@
 #include <gtkmm.h>
 #include "layoutwidgetbase.h"
 #include "layoutwidgetutils.h"
-#include <glom/libglom/data_structure/layout/layoutitem_button.h>
+#include <libglom/data_structure/layout/layoutitem_button.h>
 #include <libglademm.h>
 
 namespace Glom
@@ -41,7 +41,7 @@ public:
   explicit LabelGlom(const Glib::ustring& label, float xalign, float yalign, bool mnemonic = false);
   virtual ~LabelGlom();
 
-protected:
+private:
   void init();
 
   virtual App_Glom* get_application();
