@@ -24,6 +24,9 @@
 #include <gtkmm.h>
 #include <libglademm.h>
 
+namespace Glom
+{
+
 class PlaceHolder : public Gtk::VBox
 {
 public:
@@ -37,8 +40,10 @@ public:
   virtual Gtk::Widget* get_child();
   virtual const Gtk::Widget* get_child() const;  
 
-protected:
+private:
   Gtk::Widget* m_pChild;
 };
 
+} //namespace Glom
+
 #endif //GLOM_UTILITY_WIDGETS_PLACEHOLDER_H
